Py4JField (py4j-java 0.10.9.7 API)

Package py4j.model

## Class Py4JField

- java.lang.Object
- - py4j.model.Py4JMember
  - - py4j.model.Py4JField

- All Implemented Interfaces:
    `java.lang.Comparable<Py4JMember>`

      public class Py4JField
      extends Py4JMember

  Model of a Java field used to create a help page.

- - ### Constructor Summary

    Constructors
    Constructor | Description
    --- | ---
    `Py4JField​(java.lang.String name, java.lang.String javadoc, java.lang.String type, java.lang.String container)` |

  - ### Method Summary

    All Methods Static Methods Instance Methods Concrete Methods
    Modifier and Type | Method | Description
    --- | --- | ---
    `static Py4JField` | `buildField​(java.lang.reflect.Field field)` |
    `java.lang.String` | `getContainer()` |
    `java.lang.String` | `getSignature​(boolean shortName)` |
    `java.lang.String` | `getType()` |

    - ### Methods inherited from class py4j.model.Py4JMember

      `compareTo, equals, getJavadoc, getName, hashCode`

    - ### Methods inherited from class java.lang.Object

      `clone, finalize, getClass, notify, notifyAll, toString, wait, wait, wait`

- - ### Constructor Detail

    - #### Py4JField

          public Py4JField​(java.lang.String name,
                           java.lang.String javadoc,
                           java.lang.String type,
                           java.lang.String container)

  - ### Method Detail

    - #### buildField

          public static final Py4JField buildField​(java.lang.reflect.Field field)

    - #### getContainer

          public java.lang.String getContainer()

    - #### getSignature

          public java.lang.String getSignature​(boolean shortName)

      Specified by:
        `getSignature` in class `Py4JMember`

    - #### getType

          public java.lang.String getType()